@@ -47,6 +47,12 @@
 
 #include "connection-capabilities.h"
 
+#ifdef HAVE_LIBINTL_H
+#   include <libintl.h>
+#else
+#   define dgettext(domain, msgid) (msgid)
+#endif
+
 enum
 {
     PROP_PARAMETERS = 1,
@@ -777,3 +783,12 @@ haze_connection_handle_inspect (HazeConnection *conn,
     g_assert (tp_handle_is_valid (handle_repo, handle, NULL));
     return tp_handle_inspect (handle_repo, handle);
 }
+
+/**
+ * Get the group that "most" libpurple prpls will use for ungrouped contacts.
+ */
+const gchar *
+haze_get_fallback_group (void)
+{
+  return dgettext ("pidgin", "Buddies");
+}
